import { IComputedValue } from "mobx";
import type { TableDataColumn, TableDataRow, TableRowId } from "./index";
export type CreatedTableState<DataItem> = ReturnType<typeof createTableState<DataItem>>;
export type StorableCreateTableState<DataItem> = ReturnType<typeof toJSON<DataItem>>;
export interface CreateTableStateParams<ResourceItem = any> {
    dataItems: IComputedValue<ResourceItem[]>;
    /**
     * Columns definition as `Table.props.columns`.
     * Used to build `Table.props.rows` state.
     */
    headingColumns: TableDataColumn<ResourceItem>[];
    /**
     * Allows to customize row before processing by table (e.g. make `selectable`)
     */
    customizeRows?: (row: TableDataRow<ResourceItem>) => Partial<TableDataRow<ResourceItem>>;
    /**
     * Provide identification for data items
     * By default, tries to get unique ID via `dataItem.getById()` or `dataItem.id`
     */
    getRowId?: (dataItem: ResourceItem) => TableRowId;
}
export declare function createTableState<DataItem = any>({ headingColumns, dataItems, customizeRows, getRowId }: CreateTableStateParams<DataItem>): {
    searchText: import("mobx").IObservableValue<string>;
    columnSizes: import("mobx").ObservableMap<string, string>;
    columnsOrder: import("mobx").IObservableArray<string>;
    hiddenColumns: import("mobx").ObservableSet<string>;
    sortedColumns: import("mobx").ObservableMap<string, "asc" | "desc">;
    tableColumns: IComputedValue<TableDataColumn<DataItem>[]>;
    tableColumnsAll: TableDataColumn<DataItem>[];
    tableRows: IComputedValue<TableDataRow<DataItem>[]>;
    sortedTableRows: IComputedValue<TableDataRow<DataItem>[]>;
    searchResultTableRows: IComputedValue<TableDataRow<DataItem>[]>;
    selectedRowsId: import("mobx").ObservableSet<TableRowId>;
    selectedTableRowsAll: IComputedValue<TableDataRow<DataItem>[]>;
    selectedTableRowsFiltered: IComputedValue<TableDataRow<DataItem>[]>;
};
export interface ImportStateParams<DataItem> {
    tableState: CreatedTableState<DataItem>;
    storedState?: StorableCreateTableState<DataItem>;
}
export declare function importState<DataItem>({ tableState, storedState }: ImportStateParams<DataItem>): void;
export declare function toJSON<DataItem>(state: CreatedTableState<DataItem>): {
    searchText: string;
    hiddenColumns: string[];
    selectedRowsId: TableRowId[];
    sortedColumns: [string, "asc" | "desc"][];
    columnsOrder: string[];
    columnsSizes: [string, string][];
};
